SuperFCMConfig class

Configuration class for SuperFCM

Constructors

SuperFCMConfig({required String appId, bool shouldMonitorTokenChange = true, bool cacheOnOffline = true, Duration? maxCacheDuration, LogLevel logLevel = LogLevel.info, bool autoTrackSessions = true, Duration sessionBackgroundThreshold = const Duration(seconds: 30), Duration sessionInactivityThreshold = const Duration(minutes: 30)})
const

Properties

appId → String
The unique application identifier for SuperFCM.
final
autoTrackSessions → bool
Whether to automatically track and update session counts.
final
cacheOnOffline → bool
Whether to cache requests that were made offline.
final
hashCode → int
The hash code for this object.
no setterinherited
logLevel → LogLevel
The minimum log level to display.
final
maxCacheDuration → Duration?
Duration for how long to retain attempts for retry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionBackgroundThreshold → Duration
The minimum time the app must be in the background to count as a new session.
final
sessionInactivityThreshold → Duration
The maximum time of user inactivity before starting a new session.
final
shouldMonitorTokenChange → bool
Whether to monitor FCM token changes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited